@@ -23,7 +23,11 @@ tasklist_icon_get_pixmap (TasklistTask *task)
 	if (task == NULL)
 		return 0;
 	
+	gdk_error_trap_push ();
 	wmhints = XGetWMHints (GDK_DISPLAY (), task->gwmh_task->xwin);
+	gdk_flush ();
+	if (gdk_error_trap_pop ())
+		return 0;
 
 	if (!wmhints)
 		return 0;
@@ -212,6 +216,7 @@ tasklist_icon_check_mini (TasklistTask *task)
 		gdk_pixmap_unref (mask);
 	}
 
+	gdk_flush ();
 	gdk_error_trap_pop ();
 
 	g_free (atomdata);
@@ -365,13 +370,18 @@ tasklist_icon_destroy (TasklistTask *task)
 	if (task == NULL)
 		return;
 	
-	if (task->icon->normal != task->tasklist->unknown_icon->normal)
+	if (task->icon->normal != task->tasklist->unknown_icon->normal) {
 		gdk_pixbuf_unref (task->icon->normal);
+		task->icon->normal = NULL;
+	}
 	
-	if (task->icon->minimized != task->tasklist->unknown_icon->minimized)
+	if (task->icon->minimized != task->tasklist->unknown_icon->minimized) {
 		gdk_pixbuf_unref (task->icon->minimized);
+		task->icon->minimized = NULL;
+	}
 
 	g_free (task->icon);
+	task->icon = NULL;
 }
 
 /* Stolen from gnome-pixmap.c */
