@@ -79,8 +79,8 @@ launch (Launcher *launcher, int argc, char *argv[])
 
 		if (goad_id != NULL) {
 			load_extern_applet (goad_id, NULL,
-					    panels->data,
-					    0, FALSE, FALSE);
+					    NULL, -1,
+					    FALSE, FALSE);
 		} else {
 			g_warning (_("Can't get goad_id from desktop entry!"));
 		}
@@ -917,7 +917,9 @@ launcher_file_name (const char *base)
 #ifdef PER_SESSION_CONFIGURATION
 	/* FIXME: this needs to do stuff, or perhaps just ignore per session
 	 * configs */
+#ifdef __GNUC__
 #warning FIXME: per session config must be done for launchers
+#endif
 #else
 	return g_strdup_printf ("%s/.gnome/panel.d/default/launchers/%s",
 				g_get_home_dir (),
