@@ -38,6 +38,20 @@ extern char *merge_merge_dir;
 
 extern GlobalConfig global_config;
 
+static void
+print_languages (void)
+{
+	FILE *out = fopen ("/tmp/languages", "a");
+	GList *list = gnome_i18n_get_language_list ("LC_MESSAGES");
+		fprintf (out, "START\n");
+	while (list) {
+		fprintf (out, "%s\n", (char *)list->data);
+		list = list->next;
+	}
+		fprintf (out, "END\n");
+	fclose (out);
+}
+
 void
 init_fr_chunks (void)
 {
@@ -116,6 +130,9 @@ get_presorted_from(GSList *list, const char *dir, gboolean merged)
 gboolean
 fr_is_subdir (const char *dir, const char *superdir, int superdir_len)
 {
+	if (superdir == NULL || superdir_len == 0)
+		return FALSE;
+
 	if (strncmp (dir, superdir, superdir_len-1) == 0 &&
 	    (dir[superdir_len-1] == '/' ||
 	     dir[superdir_len-1] == '\0')) {
@@ -417,6 +434,7 @@ fr_fill_dir(FileRec *fr, int sublevels)
 			tryexec_path = NULL;
 
 			dentry = gnome_desktop_entry_load_unconditional (name);
+			print_languages ();
 			if (dentry != NULL &&
 			    dentry->tryexec != NULL) {
 				tryexec_path = panel_is_program_in_path (dentry->tryexec);
@@ -429,7 +447,10 @@ fr_fill_dir(FileRec *fr, int sublevels)
 			}
 			if (dentry != NULL) {
 				ffr = g_chunk_new0 (FileRec, file_chunk);
-				ffr->type = FILE_REC_FILE;
+				if (! g_strcasecmp (dentry->type, "separator"))
+					ffr->type = FILE_REC_SEP;
+				else
+					ffr->type = FILE_REC_FILE;
 				ffr->merged = merged;
 				ffr->name = name;
 				ffr->mtime = s.st_mtime;
@@ -519,6 +540,7 @@ fr_read_dir (DirRec *dr, const char *mdir, struct stat *dstat,
 	    stat (fname, &s) != -1) {
 		GnomeDesktopEntry *dentry;
 		dentry = gnome_desktop_entry_load(fname);
+		print_languages ();
 		if (dentry != NULL) {
 			g_free (fr->icon);
 			fr->icon = dentry->icon;
@@ -683,6 +705,7 @@ fr_check_and_reread (FileRec *fr)
 				if(ddr->dentrymtime != s.st_mtime) {
 					GnomeDesktopEntry *dentry;
 					dentry = gnome_desktop_entry_load(p);
+					print_languages ();
 					if(dentry) {
 						g_free(ffr->icon);
 						ffr->icon = dentry->icon;
@@ -717,6 +740,7 @@ fr_check_and_reread (FileRec *fr)
 				if(ffr->mtime != s.st_mtime) {
 					GnomeDesktopEntry *dentry;
 					dentry = gnome_desktop_entry_load(ffr->name);
+					print_languages ();
 					if (dentry != NULL) {
 						/* take over memory */
 						g_free (ffr->icon);
